@@ -6,7 +6,7 @@ import warnings
 class RSA:
     @staticmethod
     def generate_key():
-        warnings.warn("此方法已弃用，不推荐使用", DeprecationWarning)
+        warnings.warn("此方法已弃用，不推荐使用，切换到lesscode-utils包里", DeprecationWarning)
         try:
             Rsa = importlib.import_module("Cryptodome.PublicKey.RSA")
             Random = importlib.import_module("Cryptodome.Random")
@@ -27,7 +27,7 @@ class RSA:
 
     @staticmethod
     def encrypt(text: str, public_key: str, encoding='utf-8'):
-        warnings.warn("此方法已弃用，不推荐使用", DeprecationWarning)
+        warnings.warn("此方法已弃用，不推荐使用，切换到lesscode-utils包里", DeprecationWarning)
         try:
             Rsa = importlib.import_module("Cryptodome.PublicKey.RSA")
             Cipher_pkcs1_v1_5 = importlib.import_module("Cryptodome.Cipher.PKCS1_v1_5")
@@ -40,7 +40,7 @@ class RSA:
 
     @staticmethod
     def decrypt(text: str, private_key: str, encoding='utf-8'):
-        warnings.warn("此方法已弃用，不推荐使用", DeprecationWarning)
+        warnings.warn("此方法已弃用，不推荐使用，切换到lesscode-utils包里", DeprecationWarning)
         try:
             Rsa = importlib.import_module("Cryptodome.PublicKey.RSA")
             Cipher_pkcs1_v1_5 = importlib.import_module("Cryptodome.Cipher.PKCS1_v1_5")
